==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiWidgets/QStyle_shell.h <==
#ifndef QSTYLE_SHELL_H
#define QSTYLE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWidgets/qstyle.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtWidgets/qapplication.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QStyle_shell : public QStyle, public QtJambiShellInterface
{
public:
    QStyle_shell();
    ~QStyle_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void drawComplexControl(QStyle::ComplexControl cc0, const QStyleOptionComplex* opt1, QPainter* p2, const QWidget* widget3) const override;
    void drawControl(QStyle::ControlElement element0, const QStyleOption* opt1, QPainter* p2, const QWidget* w3) const override;
    void drawItemPixmap(QPainter* painter0, const QRect& rect1, int alignment2, const QPixmap& pixmap3) const override;
    void drawItemText(QPainter* painter0, const QRect& rect1, int flags2, const QPalette& pal3, bool enabled4, const QString& text5, QPalette::ColorRole textRole6) const override;
    void drawPrimitive(QStyle::PrimitiveElement pe0, const QStyleOption* opt1, QPainter* p2, const QWidget* w3) const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QPixmap generatedIconPixmap(QIcon::Mode iconMode0, const QPixmap& pixmap1, const QStyleOption* opt2) const override;
    QStyle::SubControl hitTestComplexControl(QStyle::ComplexControl cc0, const QStyleOptionComplex* opt1, const QPoint& pt2, const QWidget* widget3) const override;
    QRect itemPixmapRect(const QRect& r0, int flags1, const QPixmap& pixmap2) const override;
    QRect itemTextRect(const QFontMetrics& fm0, const QRect& r1, int flags2, bool enabled3, const QString& text4) const override;
    int layoutSpacing(QSizePolicy::ControlType control10, QSizePolicy::ControlType control21, Qt::Orientation orientation2, const QStyleOption* option3, const QWidget* widget4) const override;
    int pixelMetric(QStyle::PixelMetric metric0, const QStyleOption* option1, const QWidget* widget2) const override;
    void polish(QApplication* application0) override;
    void polish(QPalette& palette0) override;
    void polish(QWidget* widget0) override;
    QSize sizeFromContents(QStyle::ContentsType ct0, const QStyleOption* opt1, const QSize& contentsSize2, const QWidget* w3) const override;
    QIcon standardIcon(QStyle::StandardPixmap standardIcon0, const QStyleOption* option1, const QWidget* widget2) const override;
    QPalette standardPalette() const override;
    QPixmap standardPixmap(QStyle::StandardPixmap standardPixmap0, const QStyleOption* opt1, const QWidget* widget2) const override;
    int styleHint(QStyle::StyleHint stylehint0, const QStyleOption* opt1, const QWidget* widget2, QStyleHintReturn* returnData3) const override;
    QRect subControlRect(QStyle::ComplexControl cc0, const QStyleOptionComplex* opt1, QStyle::SubControl sc2, const QWidget* widget3) const override;
    QRect subElementRect(QStyle::SubElement subElement0, const QStyleOption* option1, const QWidget* widget2) const override;
    void timerEvent(QTimerEvent* event0) override;
    void unpolish(QApplication* application0) override;
    void unpolish(QWidget* widget0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QStyle_access : public QStyle
{
    void __qt_drawComplexControl_QStyle_ComplexControl_const_QStyleOptionComplex_ptr_QPainter_ptr_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cc0, QtJambiNativeID opt1, QtJambiNativeID p2, QtJambiNativeID widget3) const;
    void __qt_drawControl_QStyle_ControlElement_const_QStyleOption_ptr_QPainter_ptr_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint element0, QtJambiNativeID opt1, QtJambiNativeID p2, QtJambiNativeID w3) const;
    void __qt_drawItemPixmap_QPainter_ptr_cref_QRect_int_cref_QPixmap_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID rect1, jint alignment2, QtJambiNativeID pixmap3) const;
    void __qt_drawItemText_QPainter_ptr_cref_QRect_int_cref_QPalette_bool_cref_QString_QPalette_ColorRole_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID rect1, jint flags2, QtJambiNativeID pal3, jboolean enabled4, jstring text5, jint textRole6) const;
    void __qt_drawPrimitive_QStyle_PrimitiveElement_const_QStyleOption_ptr_QPainter_ptr_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pe0, QtJambiNativeID opt1, QtJambiNativeID p2, QtJambiNativeID w3) const;
    jobject __qt_generatedIconPixmap_QIcon_Mode_cref_QPixmap_const_QStyleOption_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint iconMode0, QtJambiNativeID pixmap1, QtJambiNativeID opt2) const;
    jobject __qt_hitTestComplexControl_QStyle_ComplexControl_const_QStyleOptionComplex_ptr_cref_QPoint_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cc0, QtJambiNativeID opt1, QtJambiNativeID pt2, QtJambiNativeID widget3) const;
    jobject __qt_itemPixmapRect_cref_QRect_int_cref_QPixmap_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID r0, jint flags1, QtJambiNativeID pixmap2) const;
    jobject __qt_itemTextRect_cref_QFontMetrics_cref_QRect_int_bool_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID fm0, QtJambiNativeID r1, jint flags2, jboolean enabled3, jstring text4) const;
    jint __qt_layoutSpacing_QSizePolicy_ControlType_QSizePolicy_ControlType_Qt_Orientation_const_QStyleOption_ptr_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint control10, jint control21, jint orientation2, QtJambiNativeID option3, QtJambiNativeID widget4) const;
    jint __qt_pixelMetric_QStyle_PixelMetric_const_QStyleOption_ptr_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint metric0, QtJambiNativeID option1, QtJambiNativeID widget2) const;
    void __qt_polish_QApplication_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID application0);
    void __qt_polish_ref_QPalette(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID palette0);
    void __qt_polish_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0);
    jobject __qt_sizeFromContents_QStyle_ContentsType_const_QStyleOption_ptr_cref_QSize_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint ct0, QtJambiNativeID opt1, QtJambiNativeID contentsSize2, QtJambiNativeID w3) const;
    jobject __qt_standardIcon_QStyle_StandardPixmap_const_QStyleOption_ptr_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint standardIcon0, QtJambiNativeID option1, QtJambiNativeID widget2) const;
    jobject __qt_standardPalette_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_standardPixmap_QStyle_StandardPixmap_const_QStyleOption_ptr_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint standardPixmap0, QtJambiNativeID opt1, QtJambiNativeID widget2) const;
    jint __qt_styleHint_QStyle_StyleHint_const_QStyleOption_ptr_const_QWidget_ptr_QStyleHintReturn_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint stylehint0, QtJambiNativeID opt1, QtJambiNativeID widget2, QtJambiNativeID returnData3) const;
    jobject __qt_subControlRect_QStyle_ComplexControl_const_QStyleOptionComplex_ptr_QStyle_SubControl_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cc0, QtJambiNativeID opt1, jint sc2, QtJambiNativeID widget3) const;
    jobject __qt_subElementRect_QStyle_SubElement_const_QStyleOption_ptr_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint subElement0, QtJambiNativeID option1, QtJambiNativeID widget2) const;
    void __qt_unpolish_QApplication_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID application0);
    void __qt_unpolish_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0);
};

#endif // QSTYLE_SHELL_H

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiWidgets/QStyle_shell.h <==
#ifndef QSTYLE_SHELL_H
#define QSTYLE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWidgets/qstyle.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtWidgets/qapplication.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QStyle_shell : public QStyle, public QtJambiShellInterface
{
public:
    QStyle_shell();
    ~QStyle_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QStyle_mshell;
    friend class QStyle_oshell;
};


class QStyle_mshell : public QStyle_shell
{
public:
    using QStyle_shell::QStyle_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QStyle_oshell : public QStyle_mshell
{
public:
    using QStyle_mshell::QStyle_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void drawComplexControl(QStyle::ComplexControl cc0, const QStyleOptionComplex* opt1, QPainter* p2, const QWidget* widget3) const override;
    void drawControl(QStyle::ControlElement element0, const QStyleOption* opt1, QPainter* p2, const QWidget* w3) const override;
    void drawItemPixmap(QPainter* painter0, const QRect& rect1, int alignment2, const QPixmap& pixmap3) const override;
    void drawItemText(QPainter* painter0, const QRect& rect1, int flags2, const QPalette& pal3, bool enabled4, const QString& text5, QPalette::ColorRole textRole6) const override;
    void drawPrimitive(QStyle::PrimitiveElement pe0, const QStyleOption* opt1, QPainter* p2, const QWidget* w3) const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QPixmap generatedIconPixmap(QIcon::Mode iconMode0, const QPixmap& pixmap1, const QStyleOption* opt2) const override;
    QStyle::SubControl hitTestComplexControl(QStyle::ComplexControl cc0, const QStyleOptionComplex* opt1, const QPoint& pt2, const QWidget* widget3) const override;
    QRect itemPixmapRect(const QRect& r0, int flags1, const QPixmap& pixmap2) const override;
    QRect itemTextRect(const QFontMetrics& fm0, const QRect& r1, int flags2, bool enabled3, const QString& text4) const override;
    int layoutSpacing(QSizePolicy::ControlType control10, QSizePolicy::ControlType control21, Qt::Orientation orientation2, const QStyleOption* option3, const QWidget* widget4) const override;
    int pixelMetric(QStyle::PixelMetric metric0, const QStyleOption* option1, const QWidget* widget2) const override;
    void polish(QApplication* application0) override;
    void polish(QPalette& palette0) override;
    void polish(QWidget* widget0) override;
    QSize sizeFromContents(QStyle::ContentsType ct0, const QStyleOption* opt1, const QSize& contentsSize2, const QWidget* w3) const override;
    QIcon standardIcon(QStyle::StandardPixmap standardIcon0, const QStyleOption* option1, const QWidget* widget2) const override;
    QPalette standardPalette() const override;
    QPixmap standardPixmap(QStyle::StandardPixmap standardPixmap0, const QStyleOption* opt1, const QWidget* widget2) const override;
    int styleHint(QStyle::StyleHint stylehint0, const QStyleOption* opt1, const QWidget* widget2, QStyleHintReturn* returnData3) const override;
    QRect subControlRect(QStyle::ComplexControl cc0, const QStyleOptionComplex* opt1, QStyle::SubControl sc2, const QWidget* widget3) const override;
    QRect subElementRect(QStyle::SubElement subElement0, const QStyleOption* option1, const QWidget* widget2) const override;
    void timerEvent(QTimerEvent* event0) override;
    void unpolish(QApplication* application0) override;
    void unpolish(QWidget* widget0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QStyle_access : public QStyle
{
    void __qt_drawComplexControl_QStyle_ComplexControl_const_QStyleOptionComplex_ptr_QPainter_ptr_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cc0, QtJambiNativeID opt1, QtJambiNativeID p2, QtJambiNativeID widget3) const;
    void __qt_drawControl_QStyle_ControlElement_const_QStyleOption_ptr_QPainter_ptr_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint element0, QtJambiNativeID opt1, QtJambiNativeID p2, QtJambiNativeID w3) const;
    void __qt_drawItemPixmap_QPainter_ptr_cref_QRect_int_cref_QPixmap_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID rect1, jint alignment2, QtJambiNativeID pixmap3) const;
    void __qt_drawItemText_QPainter_ptr_cref_QRect_int_cref_QPalette_bool_cref_QString_QPalette_ColorRole_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID rect1, jint flags2, QtJambiNativeID pal3, jboolean enabled4, jstring text5, jint textRole6) const;
    void __qt_drawPrimitive_QStyle_PrimitiveElement_const_QStyleOption_ptr_QPainter_ptr_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pe0, QtJambiNativeID opt1, QtJambiNativeID p2, QtJambiNativeID w3) const;
    jobject __qt_generatedIconPixmap_QIcon_Mode_cref_QPixmap_const_QStyleOption_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint iconMode0, QtJambiNativeID pixmap1, QtJambiNativeID opt2) const;
    jobject __qt_hitTestComplexControl_QStyle_ComplexControl_const_QStyleOptionComplex_ptr_cref_QPoint_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cc0, QtJambiNativeID opt1, QtJambiNativeID pt2, QtJambiNativeID widget3) const;
    jobject __qt_itemPixmapRect_cref_QRect_int_cref_QPixmap_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID r0, jint flags1, QtJambiNativeID pixmap2) const;
    jobject __qt_itemTextRect_cref_QFontMetrics_cref_QRect_int_bool_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID fm0, QtJambiNativeID r1, jint flags2, jboolean enabled3, jstring text4) const;
    jint __qt_layoutSpacing_QSizePolicy_ControlType_QSizePolicy_ControlType_Qt_Orientation_const_QStyleOption_ptr_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint control10, jint control21, jint orientation2, QtJambiNativeID option3, QtJambiNativeID widget4) const;
    jint __qt_pixelMetric_QStyle_PixelMetric_const_QStyleOption_ptr_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint metric0, QtJambiNativeID option1, QtJambiNativeID widget2) const;
    void __qt_polish_QApplication_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID application0);
    void __qt_polish_ref_QPalette(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID palette0);
    void __qt_polish_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0);
    jobject __qt_sizeFromContents_QStyle_ContentsType_const_QStyleOption_ptr_cref_QSize_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint ct0, QtJambiNativeID opt1, QtJambiNativeID contentsSize2, QtJambiNativeID w3) const;
    jobject __qt_standardIcon_QStyle_StandardPixmap_const_QStyleOption_ptr_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint standardIcon0, QtJambiNativeID option1, QtJambiNativeID widget2) const;
    jobject __qt_standardPalette_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_standardPixmap_QStyle_StandardPixmap_const_QStyleOption_ptr_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint standardPixmap0, QtJambiNativeID opt1, QtJambiNativeID widget2) const;
    jint __qt_styleHint_QStyle_StyleHint_const_QStyleOption_ptr_const_QWidget_ptr_QStyleHintReturn_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint stylehint0, QtJambiNativeID opt1, QtJambiNativeID widget2, QtJambiNativeID returnData3) const;
    jobject __qt_subControlRect_QStyle_ComplexControl_const_QStyleOptionComplex_ptr_QStyle_SubControl_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cc0, QtJambiNativeID opt1, jint sc2, QtJambiNativeID widget3) const;
    jobject __qt_subElementRect_QStyle_SubElement_const_QStyleOption_ptr_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint subElement0, QtJambiNativeID option1, QtJambiNativeID widget2) const;
    void __qt_unpolish_QApplication_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID application0);
    void __qt_unpolish_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0);
};

#endif // QSTYLE_SHELL_H
